<!--维修维护-->
<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParams" :inline="true" label-suffix="：">
        <el-form-item label="设备名称">
          <el-input
            :clearable="true"
            placeholder="请输入设备名称"
            v-model="queryParams.name"
            clearable
          />
        </el-form-item>
        <el-form-item label="维修状态">
          <el-select
            placeholder="请选择维修状态"
            v-model="queryParams.toexamain"
            clearable
            filterable
          >
            <el-option
              v-for="item in toExmianOpt"
              :key="item.value"
              :label="item.name"
              :value="item.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" @click="handleSearch">
            搜索
          </el-button>
          <el-button icon="el-icon-refresh" @click="handleReset">
            重置
          </el-button>
        </el-form-item>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">

      </div>
      <el-table
        border
        size="mini"
        v-loading="loading"
        ref="multipleSelection"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @selection-change="handleSelectionChange"
        row-key="id"
      >
        <el-table-column reserve-selection type="selection" width="55" align="center"></el-table-column>
        <el-table-column type="index" width="70" label="序号" align="center">
        </el-table-column>
        <el-table-column
          prop="name"
          show-overflow-tooltip
          align="center"
          label="设备名称"
          min-width="200"
        />
        <el-table-column
          prop="toexamain"
          show-overflow-tooltip
          align="center"
          label="维修状态"
          min-width="100"
          :formatter="({toexamain}) => dictionaryEscape(toExmianOpt,toexamain)"
        />
        <el-table-column
          prop="address"
          show-overflow-tooltip
          align="center"
          label="地址"
          min-width="200"
        />
        <el-table-column show-overflow-tooltip min-width="100" align="center" fixed="right" label="操作">
          <template v-slot="{ row }">
            <div class="table-column-btn">
              <el-link
                v-if="row.toexamain === '2'"
                type="primary"
                :underline="false"
                @click="showDialog('TakingOrderDialog',row)"
              >
                接单
              </el-link>
              <el-link
                v-if="row.toexamain === '3' || row.toexamain === '8'"
                type="primary"
                :underline="false"
                @click="showDialog('RegisterDialog',row)"
              >
                登记维修信息
              </el-link>
              <el-link
                v-if="row.toexamain === '2' || row.toexamain === '3' "
                type="primary"
                :underline="false"
                @click="showDialog('TransferOrderDialog',row)"
              >
                转单申请
              </el-link>
              <el-link
                v-if="row.toexamain === '3' || row.toexamain === '8'"
                type="primary"
                :underline="false"
                @click="showDialog('DelayDialog',row)"
              >
                延期申请
              </el-link>
              <el-link
                v-else-if="row.toexamain === '9'"
                type="primary"
                :underline="false"
                @click="showDialog('DetailsDialog',row)"
              >
                设备维护详情
              </el-link>
            </div>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
        align="right"
        background
        class="bbsl-pagination"
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParams.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParams.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="queryParams.total"
      ></el-pagination>
    </div>

    <!--  派遣维修人员、转单审核、延期审核、工单完成确认组件 -->
    <component
      :isShowDialog.sync="isShowDialog"
      :row-info="rowInfo"
      :is="dialogName"
      @closeDialog="closeDialog"
    />
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import {tableData} from '@/api/device/resourceInspection/maintenanceRepair'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'
import TakingOrderDialog from './components/TakingOrderDialog/index.vue'
import DelayDialog from './components/DelayDialog/index.vue'
import TransferOrderDialog from './components/TransferOrderDialog/index.vue'
import RegisterDialog from './components/RegisterDialog/index.vue'
import DetailsDialog from './components/DetailsDialog/index.vue'

export default {
  name: 'MaintenanceRepair',
  components: {
    TakingOrderDialog,
    DelayDialog,
    TransferOrderDialog,
    RegisterDialog,
    DetailsDialog
  },
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      tableData: [],
      queryParams: {
        name: '',
        toexamain: '',
        page: 1,
        pageSize: 10
      },
      sorter: [],
      toExmianOpt: (dictUtils.getDictItemsFromCache('gdsh') || []).filter(i => {
        return ['2', '3', '5', '7', '8', '9'].includes(i.value)
      }), // 是否检修
      sfxjOpt: dictUtils.getDictItemsFromCache('sfxj') || [], // 是否巡检
      xjztOpt: dictUtils.getDictItemsFromCache('xjzt') || [], // 巡检设备状态
      xjlxOpt: dictUtils.getDictItemsFromCache('xjlx') || [], // 巡检类型
      sqlxOpt: dictUtils.getDictItemsFromCache('sqlx') || [], // 申请类型
      rowInfo: {},
      dispatchedPersonnelDialog: false, // 是否显示派遣人员弹层
      dialogName: '', // 动态挂载组件名
      isShowDialog: false // 弹层显隐
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        {operation: 'LIKE', property: 'name'},
        {operation: 'IN', property: 'toexamain', value: ['2', '3', '5', '7', '8', '9'].join(',')}
      ]
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          const value = item[i.property] || i.value || ''
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return {group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
  },
  methods: {
    dictionaryEscape,

    // 获取list
    async loadData() {
      this.loading = true
      const {rows, total} = await tableData(this.computedQuery)
      this.tableData = rows
      this.queryParams.total = total
      this.loading = false
    },

    // 顶部搜索
    handleSearch() {
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.query = this.$options.data().query
      this.loadData()
    },

    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.loadData()
    },


    // 打开弹层
    showDialog(dialogName, rowInfo = {}) {
      this.dialogName = dialogName
      this.$nextTick(_ => {
        this.isShowDialog = true
        this.rowInfo = rowInfo // 保存点击行信息
      })
    },

    // 关闭弹层
    closeDialog(event) {
      switch (event) {
        case 'TakingOrderDialog':
          break
        case 'DelayDialog':
          break
        case 'RegisterDialog':
          break
        case 'TransferOrderDialog':
          break
      }
      this.loadData()
    }
  }
}
</script>
<style lang="scss" scoped>
::v-deep .table-column-btn {
  display: flex;
  justify-content: center;
  column-gap: 15px;
}
</style>
